// --------------------------------------------------------------------------------------------------------------------
// <copyright file="WindowViewModel.cs" company="Concept Architecture">
//   (c) 2010 Muhammad Umer Farooq
// </copyright>
// <summary>
//   Defines the WindowViewModel type.
// </summary>
// --------------------------------------------------------------------------------------------------------------------

namespace Hisaab.Client.Common.BaseClasses
{
    using System.Windows;
    using System.Windows.Media;

    /// <summary>
    ///  Defines the <seealso cref="WindowViewModel"/> type.
    /// </summary>
    public class WindowViewModel : TabViewModel
    {
        #region Data Members

        /// <summary>
        /// Member variable resizable
        /// </summary>
        private ResizeMode _resizeable;

        /// <summary>
        /// Member varibale _icon
        /// </summary>
        private ImageSource _icon;

        #endregion Data Members

        #region Properties

        /// <summary>
        /// Gets or sets the resize mode.
        /// </summary>
        /// <value>The resize mode.</value>
        public ResizeMode ResizeMode
        {
            get
            {
                return _resizeable;
            }

            set
            {
                RaisePropertyChangingEvent("ResizeMode");
                _resizeable = value;
                RaisePropertyChangedEvent("ResizeMode");
            }
        }

        /// <summary>
        /// Gets or sets the icon.
        /// </summary>
        /// <value>The icon.</value>
        public ImageSource Icon
        {
            get
            {
                return _icon;
            }

            set
            {
                RaisePropertyChangingEvent("Icon");
                _icon = value;
                RaisePropertyChangedEvent("Icon");
            }
        }

        #endregion Properties
    }
}