﻿// --------------------------------------------------------------------------------------------------------------------
// <copyright file="CurrencyToSymbolConverter.cs" company="Concept Architecture">
//   (c) 2010 Muhammad Umer Farooq
// </copyright>
// <summary>
//   Defines the <seealso cref="CurrencyToSymbolConverter" /> type.
// </summary>
// --------------------------------------------------------------------------------------------------------------------

namespace Hisaab.Client.Common.Converters
{
    using System;
    using System.Globalization;
    using System.Windows.Data;
    using System.Windows.Media;
    using System.Windows.Media.Imaging;

    using Hisaab.Common;

    /// <summary>
    /// Defines the <seealso cref="CurrencyToSymbolConverter"/> type.
    /// </summary>
    public class CurrencyToSymbolConverter : IValueConverter
    {
        /// <summary>
        /// Converts a value. 
        /// </summary>
        /// <returns>
        /// A converted value. If the method returns null, the valid null value is used.
        /// </returns>
        /// <param name="value">The value produced by the binding source.</param><param name="targetType">The type of the binding target property.</param><param name="parameter">The converter parameter to use.</param><param name="culture">The culture to use in the converter.</param>
        public object Convert(object value, Type targetType, object parameter, CultureInfo culture)
        {
            if (value is Currency)
            {
                switch ((Currency)value)
                {
                    case Currency.Dollar:
                        return new BitmapImage(new Uri("pack://application:,,,/Hisaab.Client.Common;component/Resources/Images/24/Flags/USA.png"));
                    case Currency.PoundSterling:
                        return new BitmapImage(new Uri("pack://application:,,,/Hisaab.Client.Common;component/Resources/Images/24/Flags/UnitedKingdom.png"));
                    case Currency.Euro:
                        return new BitmapImage(new Uri("pack://application:,,,/Hisaab.Client.Common;component/Resources/Images/24/Flags/EU.png"));
                    case Currency.PakistaniRupees:
                        return new BitmapImage(new Uri("pack://application:,,,/Hisaab.Client.Common;component/Resources/Images/24/Flags/Pakistan.png"));
                    default:
                        throw new ArgumentOutOfRangeException("value");
                }
            }

            return null;
        }

        /// <summary>
        /// Converts a value. 
        /// </summary>
        /// <returns>
        /// A converted value. If the method returns null, the valid null value is used.
        /// </returns>
        /// <param name="value">The value that is produced by the binding target.</param><param name="targetType">The type to convert to.</param><param name="parameter">The converter parameter to use.</param><param name="culture">The culture to use in the converter.</param>
        public object ConvertBack(object value, Type targetType, object parameter, CultureInfo culture)
        {
            return value;
        }
}
}
