// --------------------------------------------------------------------------------------------------------------------
// <copyright file="SessionManager.cs" company="Concept Architecture">
//   (c) 2010 Muhammad Umer Farooq
// </copyright>
// <summary>
//   Defines the <seealso cref="SessionManager" /> type.
// </summary>
// --------------------------------------------------------------------------------------------------------------------

namespace Hisaab.Client.Common.Services
{
    using System.Globalization;
    using System.Windows;
    using System.Windows.Markup;

    /// <summary>
    /// Defines the <seealso cref="SessionManager"/> type.
    /// </summary>
    public class SessionManager : ISession
    {
        /// <summary>
        /// Gets or sets the themes.
        /// </summary>
        /// <value>
        /// The themes.
        /// </value>
        public Themes Theme { get; set; }

        /// <summary>
        /// Gets or sets the user.
        /// </summary>
        /// <value>
        /// The user.
        /// </value>
        public int LoggedUser { get; set; }

        /// <summary>
        /// Gets the application.
        /// </summary>
        /// <value>
        /// The application.
        /// </value>
        public Application Application
        {
            get
            {
                return Application.Current;
            }
        }

        /// <summary>
        /// Sets the currency.
        /// </summary>
        /// <param name="userCurrencyLocale">The user currency locale.</param>
        public void SetCurrency(string userCurrencyLocale)
        {
            FrameworkElement.LanguageProperty.OverrideMetadata(typeof(FrameworkElement), new FrameworkPropertyMetadata(XmlLanguage.GetLanguage(GetUserCurrencyCulture(userCurrencyLocale).IetfLanguageTag)));
        }

        /// <summary>
        /// Gets the user currency culture.
        /// </summary>
        /// <param name="userCurrencyLocale">The user currency locale.</param>
        /// <returns>
        /// User currency culture
        /// </returns>
        private CultureInfo GetUserCurrencyCulture(string userCurrencyLocale)
        {
            switch (userCurrencyLocale.Trim())
            {
                case "$":
                    return CultureInfo.GetCultureInfo("en-US");
                case "":
                    return CultureInfo.GetCultureInfo("en-GB");
                case "Rs":
                    return CultureInfo.GetCultureInfo("ur-PK");
                case "":
                    return CultureInfo.GetCultureInfo("fr-FR");
                default:
                    return CultureInfo.CurrentCulture;
            }
        }
    }
}