﻿// --------------------------------------------------------------------------------------------------------------------
// <copyright file="AccountSummary.cs" company="Concept Architecture">
//   (c) 2010 Muhammad Umer Farooq
// </copyright>
// <summary>
//   Defines the AccountSummary type.
// </summary>
// --------------------------------------------------------------------------------------------------------------------

namespace Hisaab.Client.Model
{
    using System.Collections.Generic;

    /// <summary>
    /// Defines the <seealso cref="AccountSummary"/> type.
    /// </summary>
    public class AccountSummary : ModelBase
    {
        /// <summary>
        /// Member variable _transactionCount
        /// </summary>
        private int _transactionCount;

        /// <summary>
        /// Member variable _endingBalance
        /// </summary>
        private decimal _endingBalance;

        /// <summary>
        /// Member variable _chartData
        /// </summary>
        private KeyValuePair<string, decimal>[] _chartData;

        /// <summary>
        /// Gets or sets the transaction count.
        /// </summary>
        /// <value>
        /// The transaction count.
        /// </value>
        public int TransactionCount
        {
            get
            {
                return _transactionCount;
            }

            set
            {
                if (_transactionCount != value)
                {
                    _transactionCount = value;
                    RaisePropertyChangedEvent("TransactionCount");
                }
            }
        }

        /// <summary>
        /// Gets or sets the ending balance.
        /// </summary>
        /// <value>
        /// The ending balance.
        /// </value>
        public decimal EndingBalance
        {
            get
            {
                return _endingBalance;
            }

            set
            {
                if (_endingBalance != value)
                {
                    _endingBalance = value;
                    RaisePropertyChangedEvent("EndingBalance");
                }
            }
        }

        /// <summary>
        /// Gets or sets the chart data.
        /// </summary>
        /// <value>
        /// The chart data.
        /// </value>
        public KeyValuePair<string, decimal>[] ChartData
        {
            get
            {
                return _chartData;
            }

            set
            {
                if (_chartData != value)
                {
                    _chartData = value;
                    RaisePropertyChangedEvent("ChartData");
                }
            }
        }
    }
}