﻿// --------------------------------------------------------------------------------------------------------------------
// <copyright file="TransactionTypeImageConverter.cs" company="Concept Architecture">
//   (c) 2010 Muhammad Umer Farooq
// </copyright>
// <summary>
//   Defines the TransactionTypeImageConverter type.
// </summary>
// --------------------------------------------------------------------------------------------------------------------

namespace Hisaab.Client.Modules.Core.Converters
{
    using System;
    using System.Globalization;
    using System.Windows.Data;
    using System.Windows.Media;
    using System.Windows.Media.Imaging;

    using Hisaab.Client.Model;

    /// <summary>
    /// Defines the <seealso cref="TransactionTypeImageConverter"/> type.
    /// </summary>
    [ValueConversion(typeof(ImageSource), typeof(int))]
    public class TransactionTypeImageConverter : IValueConverter
    {
        /// <summary>
        /// Gets or sets a value indicating whether [use large icon].
        /// </summary>
        /// <value>
        ///   <c>true</c> if [use large icon]; otherwise, <c>false</c>.
        /// </value>
        public bool UseLargeIcon { get; set; }

        /// <summary>
        /// Converts a value.
        /// </summary>
        /// <returns>
        /// A converted value. If the method returns null, the valid null value is used.
        /// </returns>
        /// <param name="value">The value produced by the binding source.</param><param name="targetType">The type of the binding target property.</param><param name="parameter">The converter parameter to use.</param><param name="culture">The culture to use in the converter.</param>
        public object Convert(object value, Type targetType, object parameter, CultureInfo culture)
        {
            if (value is TransactionTypes)
            {
                if (UseLargeIcon)
                {
                    switch ((TransactionTypes)value)
                    {
                        case TransactionTypes.Expanse:
                            return
                                new BitmapImage(
                                    new Uri(
                                        "Pack://application:,,,/Hisaab.Client.Common;component/Resources/Images/16/TransactionRed.png"));
                        case TransactionTypes.Income:
                            return
                                new BitmapImage(
                                    new Uri(
                                        "Pack://application:,,,/Hisaab.Client.Common;component/Resources/Images/16/TransactionGreen.png"));
                        case TransactionTypes.Transfer:
                            return
                                new BitmapImage(
                                    new Uri(
                                        "Pack://application:,,,/Hisaab.Client.Common;component/Resources/Images/16/Transfer.png"));
                    }
                }

                switch ((TransactionTypes)value)
                {
                    case TransactionTypes.Expanse:
                        return
                            new BitmapImage(
                                new Uri(
                                    "Pack://application:,,,/Hisaab.Client.Common;component/Resources/Images/16/TransactionRed.png"));
                    case TransactionTypes.Income:
                        return
                            new BitmapImage(
                                new Uri(
                                    "Pack://application:,,,/Hisaab.Client.Common;component/Resources/Images/16/TransactionGreen.png"));
                    case TransactionTypes.Transfer:
                        return
                            new BitmapImage(
                                new Uri(
                                    "Pack://application:,,,/Hisaab.Client.Common;component/Resources/Images/16/Transfer.png"));
                }
            }

            return null;
        }

        /// <summary>
        /// Converts a value.
        /// </summary>
        /// <returns>
        /// A converted value. If the method returns null, the valid null value is used.
        /// </returns>
        /// <param name="value">The value that is produced by the binding target.</param><param name="targetType">The type to convert to.</param><param name="parameter">The converter parameter to use.</param><param name="culture">The culture to use in the converter.</param>
        public object ConvertBack(object value, Type targetType, object parameter, CultureInfo culture)
        {
            return 0;
        }
    }
}