﻿// --------------------------------------------------------------------------------------------------------------------
// <copyright file="SummaryButtonViewModel.cs" company="Concept Architecture">
//   (c) 2010 Muhammad Umer Farooq
// </copyright>
// <summary>
//   Defines the <seealso cref="SummaryButtonViewModel" /> type.
// </summary>
// --------------------------------------------------------------------------------------------------------------------

namespace Hisaab.Client.Modules.Core.Dashboard.Commands
{
    using System;
    using System.Windows.Input;

    using Hisaab.Client.Common.Events;
    using Hisaab.Client.Modules.Core.Dashboard.ViewModel;

    using Microsoft.Practices.Prism.Events;
    using Microsoft.Practices.Prism.Regions;
    using Microsoft.Practices.ServiceLocation;

    /// <summary>
    /// Defines the <seealso cref="SummaryButtonViewModel"/> type.
    /// </summary>
    public class SummaryButtonViewModel : ICommand
    {
        #region Fields

        /// <summary>
        /// Member variable m_ViewModel
        /// </summary>
        private SummaryBackStageTabViewModel _mViewModel;

        #endregion Fields

        #region Constructor

        /// <summary>
        /// Initializes a new instance of the <see cref="SummaryButtonViewModel"/> class.
        /// </summary>
        /// <param name="viewModel">The view model.</param>
        public SummaryButtonViewModel(SummaryBackStageTabViewModel viewModel)
        {
            _mViewModel = viewModel;
        }

        #endregion Constructor

        #region ICommand Members

        /// <summary>
        /// Defines the method that determines whether the command can execute in its current state.
        /// </summary>
        /// <param name="parameter">Data used by the command.  If the command does not require data to be passed, this object can be set to null.</param>
        /// <returns>
        /// true if this command can be executed; otherwise, false.
        /// </returns>
        public bool CanExecute(object parameter)
        {
            return true;
        }

        /// <summary>
        /// Occurs when changes occur that affect whether or not the command should execute.
        /// </summary>
        public event EventHandler CanExecuteChanged
        {
            add { CommandManager.RequerySuggested += value; }
            remove { CommandManager.RequerySuggested -= value; }
        }

        /// <summary>
        /// Executes the ShowModuleAViewCommand
        /// </summary>
        public void Execute(object parameter)
        {
            _mViewModel.ReloadSummary();
        }

        #endregion ICommand Members

        #region Private Methods

        /// <summary>
        /// Callback method invoked when navigation has completed.
        /// </summary>
        /// <param name="result">Provides information about the result of the navigation.</param>
        private void NavigationCompleted(NavigationResult result)
        {
            // Exit if navigation was not successful
            if (result.Result != true) return;

            // Publish ViewRequestedEvent
            var eventAggregator = ServiceLocator.Current.GetInstance<IEventAggregator>();
            var navigationCompletedEvent = eventAggregator.GetEvent<NavigationCompletedEvent>();
            navigationCompletedEvent.Publish("ModuleA");
        }

        #endregion Private Methods
    }
}