﻿// --------------------------------------------------------------------------------------------------------------------
// <copyright file="AddTransactionCommand.cs" company="Concept Architecture">
//   (c) 2010 Muhammad Umer Farooq
// </copyright>
// <summary>
//   Defines the  type.
// </summary>
// --------------------------------------------------------------------------------------------------------------------

namespace Hisaab.Client.Modules.Core.Transaction.Commands
{
    using System;
    using System.Diagnostics.Contracts;
    using System.Windows.Input;
    using Account;
    using Common;
    using Common.Events;
    using Microsoft.Practices.Prism;
    using Microsoft.Practices.Prism.Events;
    using Microsoft.Practices.Prism.Regions;
    using Microsoft.Practices.ServiceLocation;
    using Model;
    using ViewModel;

    /// <summary>
    /// Defines the <seealso cref="AddTransactionCommand"/> type.
    /// </summary>
    public class AddTransactionCommand : ICommand
    {
        #region Fields

        /// <summary>
        /// Member variable m_ViewModel
        /// </summary>
        private readonly TransactionAddButtonViewModel _viewModel;

        /// <summary>
        /// Member variable _transfer
        /// </summary>
        private readonly TransactionTypes _transfer;

        #endregion Fields

        /// <summary>
        /// Initializes a new instance of the <see cref="AddTransactionCommand"/> class.
        /// </summary>
        /// <param name="viewModel">The view model.</param>
        public AddTransactionCommand(TransactionAddButtonViewModel viewModel)
            : this(viewModel, TransactionTypes.Expanse)
        {
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="AddTransactionCommand"/> class.
        /// </summary>
        /// <param name="viewModel">The view model.</param>
        /// <param name="transfer">Transfer type</param>
        public AddTransactionCommand(TransactionAddButtonViewModel viewModel, TransactionTypes transfer)
        {
            Contract.Requires<ArgumentNullException>(viewModel != null);

            _viewModel = viewModel;
            _transfer = transfer;
        }

        /// <summary>
        /// Actions to take when CanExecute changes.
        /// </summary>
        public event EventHandler CanExecuteChanged
        {
            add { CommandManager.RequerySuggested += value; }
            remove { CommandManager.RequerySuggested -= value; }
        }

        /// <summary>
        /// Defines the method to be called when the command is invoked.
        /// </summary>
        /// <param name="parameter">Data used by the command.  If the command does not require data to be passed, this object can be set to null.</param>
        public void Execute(object parameter)
        {
            // Initialize
            var regionManager = ServiceLocator.Current.GetInstance<IRegionManager>();

            // Show Workspace
            var query = new UriQuery { { "Type", _transfer.ToString() } };
            var dashboardWorkspace = new Uri(TransactionModule.TransactionEditor + query, UriKind.Relative);
            regionManager.RequestNavigate(Regions.SecondaryRegion, dashboardWorkspace, NavigationCompleted);
        }

        /// <summary>
        /// Defines the method that determines whether the ShowModuleAViewCommand is enabled.
        /// </summary>
        /// <param name="parameter">Data used by the command.  If the command does not require data to be passed, this object can be set to null.</param>
        /// <returns>
        /// true if this command can be executed; otherwise, false.
        /// </returns>
        public bool CanExecute(object parameter)
        {
            return true;
        }

        #region Private Methods

        /// <summary>
        /// Callback method invoked when navigation has completed.
        /// </summary>
        /// <param name="result">Provides information about the result of the navigation.</param>
        private void NavigationCompleted(NavigationResult result)
        {
            if (result.Result != true)
            {
                return;
            }

            // Publish ViewRequestedEvent
            var eventAggregator = ServiceLocator.Current.GetInstance<IEventAggregator>();
            var navigationCompletedEvent = eventAggregator.GetEvent<NavigationCompletedEvent>();
            navigationCompletedEvent.Publish(AccountModule.AccountTab);
        }

        #endregion Private Methods
    }
}