﻿// --------------------------------------------------------------------------------------------------------------------
// <copyright file="TagFilterTests.cs" company="Concept Architecture">
//   (c) 2010 Muhammad Umer Farooq
// </copyright>
// <summary>
//   Defines the TagFilterTests type.
// </summary>
// --------------------------------------------------------------------------------------------------------------------

namespace Hisaab.Data.Tests.Filters
{
    using System.Data.Objects;
    using System.Linq;
    using Data.Filters;
    using Entities;
    using Microsoft.VisualStudio.TestTools.UnitTesting;

    /// <summary>
    /// Defines the <seealso cref="Hisaab.Data.Tests.Filters.TagFilterTests"/> type.
    /// </summary>
    [TestClass]
    public class TagFilterTests
    {
        /// <summary>
        /// Mock Database
        /// </summary>
        private readonly IObjectSet<Tag> _mockObjectSet = new MockObjectSet<Tag>();

        /// <summary>
        /// Initializes a new instance of the <see cref="TagFilterTests"/> class.
        /// </summary>
        public TagFilterTests()
        {
            _mockObjectSet.AddObject(new Tag { Id = 1, Name = "Tag 1" });
            _mockObjectSet.AddObject(new Tag { Id = 2, Name = "Tag 2" });
        }

        /// <summary>
        /// Filter_s the should return everything if the object to comare is null.
        /// </summary>
        [TestMethod]
        public void TagFilterShouldReturnEverythingIfTheObjectToComareIsNull()
        {
            var result = _mockObjectSet.Filter(null).ToList();

            Assert.IsNotNull(result);
            Assert.AreEqual(2, result.Count());
        }

        /// <summary>
        /// Filters the should return everything if the object to comare is uninitialized.
        /// </summary>
        [TestMethod]
        public void TagFilterShouldReturnEverythingIfTheObjectToComareIsUninitialized()
        {
            var result = _mockObjectSet.Filter(new Tag()).ToList();

            Assert.IsNotNull(result);
            Assert.AreEqual(2, result.Count());
        }

        /// <summary>
        /// Filters the should return object filtered by id.
        /// </summary>
        [TestMethod]
        public void TagFilterShouldReturnObjectFilteredById()
        {
            var result = _mockObjectSet.Filter(new Tag { Id = 2 }).ToList();

            Assert.IsNotNull(result);
            Assert.AreEqual(1, result.Count());
            Assert.AreEqual(2, result[0].Id);
            Assert.AreEqual("Tag 2", result[0].Name);
        }

        /// <summary>
        /// Filters the name of the should return object filtered by.
        /// </summary>
        [TestMethod]
        public void TagFilterShouldReturnObjectFilteredByName()
        {
            var result = _mockObjectSet.Filter(new Tag { Name = "Tag 1" }).ToList();

            Assert.IsNotNull(result);
            Assert.AreEqual(1, result.Count());
            Assert.AreEqual(1, result[0].Id);
            Assert.AreEqual("Tag 1", result[0].Name);
        }

        /// <summary>
        /// Filters the should return object filtered by name with different case.
        /// </summary>
        [TestMethod]
        public void TagFilterShouldReturnObjectFilteredByNameWithDifferentCase()
        {
            var result = _mockObjectSet.Filter(new Tag { Name = "tag 2" }).ToList();

            Assert.IsNotNull(result);
            Assert.AreEqual(1, result.Count());
            Assert.AreEqual(2, result[0].Id);
            Assert.AreEqual("Tag 2", result[0].Name);
        }
    }
}