﻿// --------------------------------------------------------------------------------------------------------------------
// <copyright file="VehicleFilterTests.cs" company="Concept Architecture">
//   (c) 2010 Muhammad Umer Farooq
// </copyright>
// <summary>
//   Defines the VehicleFilterTests type.
// </summary>
// --------------------------------------------------------------------------------------------------------------------

namespace Hisaab.Data.Tests.Filters
{
    using System.Data.Objects;
    using System.Linq;
    using Data.Filters;
    using Entities;
    using Microsoft.VisualStudio.TestTools.UnitTesting;

    /// <summary>
    /// Defines the <seealso cref="Hisaab.Data.Tests.Filters.VehicleFilterTests"/> type.
    /// </summary>
    [TestClass]
    public class VehicleFilterTests
    {
        /// <summary>
        /// Mock Database
        /// </summary>
        private readonly IObjectSet<Vehicle> _mockObjectSet = new MockObjectSet<Vehicle>();

        /// <summary>
        /// Initializes a new instance of the <see cref="VehicleFilterTests"/> class.
        /// </summary>
        public VehicleFilterTests()
        {
            _mockObjectSet.AddObject(new Vehicle { Id = 1, Title = "Vehicle 1" });
            _mockObjectSet.AddObject(new Vehicle { Id = 2, Title = "Vehicle 2" });
        }

        /// <summary>
        /// Filter_s the should return everything if the object to comare is null.
        /// </summary>
        [TestMethod]
        public void VehicleFilterShouldReturnEverythingIfTheObjectToComareIsNull()
        {
            var result = _mockObjectSet.Filter(null).ToList();

            Assert.IsNotNull(result);
            Assert.AreEqual(2, result.Count());
        }

        /// <summary>
        /// Filters the should return everything if the object to comare is uninitialized.
        /// </summary>
        [TestMethod]
        public void VehicleFilterShouldReturnEverythingIfTheObjectToComareIsUninitialized()
        {
            var result = _mockObjectSet.Filter(new Vehicle()).ToList();

            Assert.IsNotNull(result);
            Assert.AreEqual(2, result.Count());
        }

        /// <summary>
        /// Filters the should return object filtered by id.
        /// </summary>
        [TestMethod]
        public void VehicleFilterShouldReturnObjectFilteredById()
        {
            var result = _mockObjectSet.Filter(new Vehicle { Id = 2 }).ToList();

            Assert.IsNotNull(result);
            Assert.AreEqual(1, result.Count());
            Assert.AreEqual(2, result[0].Id);
            Assert.AreEqual("Vehicle 2", result[0].Title);
        }

        /// <summary>
        /// Filters the name of the should return object filtered by.
        /// </summary>
        [TestMethod]
        public void VehicleFilterShouldReturnObjectFilteredByName()
        {
            var result = _mockObjectSet.Filter(new Vehicle { Title = "Vehicle 1" }).ToList();

            Assert.IsNotNull(result);
            Assert.AreEqual(1, result.Count());
            Assert.AreEqual(1, result[0].Id);
            Assert.AreEqual("Vehicle 1", result[0].Title);
        }

        /// <summary>
        /// Filters the should return object filtered by name with different case.
        /// </summary>
        [TestMethod]
        public void VehicleFilterShouldReturnObjectFilteredByNameWithDifferentCase()
        {
            var result = _mockObjectSet.Filter(new Vehicle { Title = "Vehicle 2" }).ToList();

            Assert.IsNotNull(result);
            Assert.AreEqual(1, result.Count());
            Assert.AreEqual(2, result[0].Id);
            Assert.AreEqual("Vehicle 2", result[0].Title);
        }
    }
}