﻿// --------------------------------------------------------------------------------------------------------------------
// <copyright file="IAccountRepository.cs" company="Concept Architecture">
//   (c) 2010 Muhammad Umer Farooq
// </copyright>
// <summary>
//   Defines the <seealso cref="IAccountRepository" /> interface.
// </summary>
// --------------------------------------------------------------------------------------------------------------------

namespace Hisaab.Data.Interfaces
{
    using System.Linq;
    using Common;
    using Entities;

    /// <summary>
    /// Defines the <seealso cref="IAccountRepository"/> interface.
    /// </summary>
    public interface IAccountRepository : IBaseRepository<Account>
    {
        /// <summary>
        /// Gets the monthly balance summary.
        /// </summary>
        /// <param name="accountId">The account id.</param>
        /// <returns>
        /// List of month and balance
        /// </returns>
        IQueryable<AccountMonthlyTotal> GetMonthlyBalanceSummary(int accountId);

        /// <summary>
        /// Gets the account totals.
        /// </summary>
        /// <param name="userId">The calling user id</param>
        /// <returns>List of account totals and summary</returns>
        IQueryable<KeyValue<Account, decimal>> GetAccountTotals(int userId);
    }
}