﻿// --------------------------------------------------------------------------------------------------------------------
// <copyright file="ITransactionRepository.cs" company="Concept Architecture">
//   (c) 2010 Muhammad Umer Farooq
// </copyright>
// <summary>
//   Defines the <seealso cref="ITransactionRepository" /> interface.
// </summary>
// --------------------------------------------------------------------------------------------------------------------

namespace Hisaab.Data.Interfaces
{
    using System;
    using System.Collections.Generic;
    using Entities;

    /// <summary>
    /// Defines the <seealso cref="ITransactionRepository"/> interface.
    /// </summary>
    public interface ITransactionRepository : IBaseRepository<Transaction>
    {
        /// <summary>
        /// Queries the between dates.
        /// </summary>
        /// <param name="filter">The transaction.</param>
        /// <param name="startDate">Start date for query</param>
        /// <param name="endDate">End date for query</param>
        /// <param name="sortBy">The sort by.</param>
        /// <param name="orderBy">The order by.</param>
        /// <param name="additionalFilter">The additional filter.</param>
        /// <returns>
        /// List of transaction
        /// </returns>
        IEnumerable<Transaction> QueryBetweenDates(Transaction filter, DateTime startDate, DateTime endDate, SortByType sortBy, OrderByType orderBy, Func<Transaction, bool> additionalFilter);

        /// <summary>
        /// Queries the between dates by tag.
        /// </summary>
        /// <param name="tagId">The tag id.</param>
        /// <param name="startDate">The start date.</param>
        /// <param name="endDate">The end date.</param>
        /// <param name="sortBy">The sort by.</param>
        /// <param name="orderBy">The order by.</param>
        /// <param name="func">The func.</param>
        /// <returns>
        /// List of transaction
        /// </returns>
        IEnumerable<Transaction> QueryBetweenDatesByTag(int tagId, DateTime startDate, DateTime endDate, SortByType sortBy, OrderByType orderBy, Func<Transaction, bool> func);
    }
}