﻿// --------------------------------------------------------------------------------------------------------------------
// <copyright file="IAccountService.cs" company="Concept Architecture">
//   (c) 2010 Muhammad Umer Farooq
// </copyright>
// <summary>
//   Defines the <seealso cref="Hisaab.Business.Interfaces.IAccountService" /> interface.
// </summary>
// --------------------------------------------------------------------------------------------------------------------

namespace Hisaab.Services.Interfaces
{
    using System.Collections.Generic;
    using System.ServiceModel;

    using Hisaab.Services.Entities;

    /// <summary>
    /// Defines the <seealso cref="IAccountService"/> interface.
    /// </summary>
    [ServiceContract]
    public interface IAccountService : IServiceBase<Account>
    {
        /// <summary>
        /// Gets the by userId.
        /// </summary>
        /// <param name="id">The account userId.</param>
        /// <returns>Account matching account userId</returns>
        [OperationContract]
        Account GetById(int id);

        /// <summary>
        /// Gets the name of the by.
        /// </summary>
        /// <param name="name">The name of account to get</param>
        /// <returns>Account matching name</returns>
        [OperationContract]
        Account GetByName(string name);

        /// <summary>
        /// Gets the account summary.
        /// </summary>
        /// <param name="id">The account userId</param>
        /// <param name="userId">The caller user userId</param>
        /// <returns>Account summary object</returns>
        [OperationContract]
        AccountSummary GetAccountSummary(int id, int userId);

        /// <summary>
        /// Gets the account balance.
        /// </summary>
        /// <param name="id">The userId of account to get balance for</param>
        /// <returns>Closing balance of account</returns>
        [OperationContract]
        decimal GetAccountBalance(int id);

        /// <summary>
        /// Gets the monthly balance summary.
        /// </summary>
        /// <param name="accountId">The account userId.</param>
        /// <param name="userId">The calling user id</param>
        /// <returns>
        /// List of month and balance
        /// </returns>
        [OperationContract]
        IEnumerable<AccountMonthlyTotal> GetMonthlyBalanceSummary(int accountId, int userId);

        /// <summary>
        /// Gets the account totals.
        /// </summary>
        /// <param name="userId">The calling user id</param>
        /// <returns>List of account totals and summary</returns>
        [OperationContract]
        IEnumerable<KeyValue<Account, decimal>> GetAccountTotals(int userId);

        /// <summary>
        /// Gets all account balance.
        /// </summary>
        /// <param name="userId">The calling user id</param>
        /// <returns>Return list of accounts and all of their monthly totals</returns>
        [OperationContract]
        IEnumerable<KeyValue<Account, IEnumerable<AccountMonthlyTotal>>> GetAllAccountBalance(int userId);
    }
}