﻿// --------------------------------------------------------------------------------------------------------------------
// <copyright file="VehicleToNameConverter.cs" company="Concept Architecture">
//   (c) 2010 Muhammad Umer Farooq
// </copyright>
// <summary>
//   Defines the AccountConverter type.
// </summary>
// --------------------------------------------------------------------------------------------------------------------

namespace Hisaab.Windows.Client.Converters
{
    using System;
    using System.Globalization;
    using System.Linq;
    using System.Windows.Data;
    using Business.Entities;
    using Business.Interfaces;

    using Microsoft.Practices.ServiceLocation;

    /// <summary>
    /// Defines the <seealso cref="Hisaab.Windows.Client.Converters.VehicleToNameConverter"/> type.
    /// </summary>
    [ValueConversion(typeof(string), typeof(int))]
    public class VehicleToNameConverter : IValueConverter
    {
        /// <summary>
        /// Converts a value.
        /// </summary>
        /// <returns>
        /// A converted value. If the method returns null, the valid null value is used.
        /// </returns>
        /// <param name="value">The value produced by the binding source.</param><param name="targetType">The type of the binding target property.</param><param name="parameter">The converter parameter to use.</param><param name="culture">The culture to use in the converter.</param>
        public object Convert(object value, Type targetType, object parameter, CultureInfo culture)
        {
            if (value is int)
            {
                return ServiceLocator.Current.GetInstance<IVehicleManager>().GetById((int)value).Name;
            }

            return string.Empty;
        }

        /// <summary>
        /// Converts a value.
        /// </summary>
        /// <returns>
        /// A converted value. If the method returns null, the valid null value is used.
        /// </returns>
        /// <param name="value">The value that is produced by the binding target.</param><param name="targetType">The type to convert to.</param><param name="parameter">The converter parameter to use.</param><param name="culture">The culture to use in the converter.</param>
        public object ConvertBack(object value, Type targetType, object parameter, CultureInfo culture)
        {
            if (value is string)
            {
                var vehicle = ServiceLocator.Current.GetInstance<IVehicleManager>()
                    .List(new Vehicle { Name = value.ToString() }).FirstOrDefault();
                if (vehicle != null)
                {
                    return vehicle.Id;
                }
            }

            return 0;
        }
    }
}