﻿// --------------------------------------------------------------------------------------------------------------------
// <copyright file="AccountEditorDocument.cs" company="Concept Architecture">
//   (c) 2010 Muhammad Umer Farooq
// </copyright>
// <summary>
//   Defines the AccountsDocument type.
// </summary>
// --------------------------------------------------------------------------------------------------------------------

namespace Hisaab.Windows.Client.Documents
{
    using System;
    using System.Diagnostics.Contracts;
    using Common;
    using View;
    using ViewModel;

    /// <summary>
    /// Defines the <seealso cref="AccountEditorDocument"/> type.
    /// </summary>
    public class AccountEditorDocument : Document
    {
        /// <summary>
        /// Account editor view model
        /// </summary>
        private readonly AccountEditorViewModel _viewModel;

        /// <summary>
        /// Initializes a new instance of the <see cref="AccountEditorDocument"/> class.
        /// </summary>
        /// <param name="viewModel">The view model.</param>
        public AccountEditorDocument(AccountEditorViewModel viewModel)
            : base("Accounts")
        {
            Contract.Requires<ArgumentNullException>(viewModel != null);
            _viewModel = viewModel;
            View = new AccountEditorView { DataContext = _viewModel };
            ContextMenuGroupName = "cmAccount";

            MainWindowViewModel.SaveCommand.RegisterPotentialTarget(View.ActiveAwareness, _viewModel.SaveAccount, _viewModel.CanSaveAccount);
        }

        /// <summary>
        /// Documents the closed.
        /// </summary>
        public override void DocumentClosed()
        {
            MainWindowViewModel.SaveCommand.UnregisterPotentialTarget(View.ActiveAwareness);
        }
    }
}