﻿// --------------------------------------------------------------------------------------------------------------------
// <copyright file="AccountsDocument.cs" company="Concept Architecture">
//   (c) 2010 Muhammad Umer Farooq
// </copyright>
// <summary>
//   Defines the AccountsDocument type.
// </summary>
// --------------------------------------------------------------------------------------------------------------------

namespace Hisaab.Windows.Client.Documents
{
    using System;
    using System.Diagnostics.Contracts;
    using Common;
    using View;
    using ViewModel;

    /// <summary>
    /// Defines the <seealso cref="AccountsDocument"/> type.
    /// </summary>
    public class AccountsDocument : Document
    {
        /// <summary>
        /// Account view model
        /// </summary>
        private readonly AccountsViewModel _viewModel;

        /// <summary>
        /// Initializes a new instance of the <see cref="AccountsDocument"/> class.
        /// </summary>
        /// <param name="viewModel">The view model.</param>
        public AccountsDocument(AccountsViewModel viewModel)
            : base("Accounts")
        {
            Contract.Requires<ArgumentNullException>(viewModel != null);
            _viewModel = viewModel;
            View = new AccountsView { DataContext = _viewModel };
            ContextMenuGroupName = "cmAccount";

            AccountsViewModel.RefreshCommand.RegisterPotentialTarget(View.ActiveAwareness, _viewModel.RefreshList);
            AccountsViewModel.EditCommand.RegisterPotentialTarget(View.ActiveAwareness, _viewModel.EditAccount, _viewModel.CanEditAccount);
            AccountsViewModel.DeleteCommand.RegisterPotentialTarget(View.ActiveAwareness, _viewModel.DeleteAccount, _viewModel.CanDeleteAccount);
        }

        /// <summary>
        /// Documents the closed.
        /// </summary>
        public override void DocumentClosed()
        {
            AccountsViewModel.RefreshCommand.UnregisterPotentialTarget(View.ActiveAwareness);
            AccountsViewModel.EditCommand.UnregisterPotentialTarget(View.ActiveAwareness);
            AccountsViewModel.DeleteCommand.UnregisterPotentialTarget(View.ActiveAwareness);
        }
    }
}