﻿// --------------------------------------------------------------------------------------------------------------------
// <copyright file="TagsDocument.cs" company="Concept Architecture">
//   (c) 2010 Muhammad Umer Farooq
// </copyright>
// <summary>
//   Defines the AccountsDocument type.
// </summary>
// --------------------------------------------------------------------------------------------------------------------

namespace Hisaab.Windows.Client.Documents
{
    using System;
    using System.Diagnostics.Contracts;
    using Common;
    using View;
    using ViewModel;

    /// <summary>
    /// Defines the <seealso cref="TagsDocument"/> type.
    /// </summary>
    public class TagsDocument : Document
    {
        /// <summary>
        /// Account view model
        /// </summary>
        private readonly TagsViewModel _viewModel;

        /// <summary>
        /// Initializes a new instance of the <see cref="TagsDocument"/> class.
        /// </summary>
        /// <param name="viewModel">
        /// The view model.
        /// </param>
        public TagsDocument(TagsViewModel viewModel)
            : base("Tags")
        {
            Contract.Requires<ArgumentNullException>(viewModel != null);
            _viewModel = viewModel;
            View = new TagsView { DataContext = _viewModel };
            ContextMenuGroupName = "cmTag";

            TagsViewModel.RefreshCommand.RegisterPotentialTarget(View.ActiveAwareness, _viewModel.RefreshList);
            TagsViewModel.EditCommand.RegisterPotentialTarget(View.ActiveAwareness, _viewModel.EditTag, _viewModel.CanEditTag);
            TagsViewModel.DeleteCommand.RegisterPotentialTarget(View.ActiveAwareness, _viewModel.DeleteTag, _viewModel.CanDeleteTag);
        }

        /// <summary>
        /// Documents the closed.
        /// </summary>
        public override void DocumentClosed()
        {
            TagsViewModel.RefreshCommand.UnregisterPotentialTarget(View.ActiveAwareness);
            TagsViewModel.EditCommand.UnregisterPotentialTarget(View.ActiveAwareness);
            TagsViewModel.DeleteCommand.UnregisterPotentialTarget(View.ActiveAwareness);
        }
    }
}