﻿// --------------------------------------------------------------------------------------------------------------------
// <copyright file="VehicleTransactionEditorDocument.cs" company="Concept Architecture">
//   (c) 2010 Muhammad Umer Farooq
// </copyright>
// <summary>
//   Defines the VehicleTransactionEditorDocument type.
// </summary>
// --------------------------------------------------------------------------------------------------------------------

namespace Hisaab.Windows.Client.Documents
{
    using System;
    using System.Diagnostics.Contracts;
    using Common;
    using View;
    using ViewModel;

    /// <summary>
    /// Defines the <seealso cref="VehicleTransactionEditorDocument"/> type.
    /// </summary>
    public class VehicleTransactionEditorDocument : Document
    {
        /// <summary>
        /// Account editor view model
        /// </summary>
        private readonly VehicleTransactionEditorViewModel _viewModel;

        /// <summary>
        /// Initializes a new instance of the <see cref="VehicleTransactionEditorDocument"/> class.
        /// </summary>
        /// <param name="viewModel">The view model.</param>
        public VehicleTransactionEditorDocument(VehicleTransactionEditorViewModel viewModel)
            : base("VehicleTransaction")
        {
            Contract.Requires<ArgumentNullException>(viewModel != null);
            _viewModel = viewModel;
            View = new VehicleTransactionEditorView { DataContext = _viewModel };
            ContextMenuGroupName = "cmVehicleTransaction";

            MainWindowViewModel.SaveCommand.RegisterPotentialTarget(View.ActiveAwareness, _viewModel.SaveVehicleTransaction, _viewModel.CanSaveVehicleTransaction);
        }

        /// <summary>
        /// Documents the closed.
        /// </summary>
        public override void DocumentClosed()
        {
            MainWindowViewModel.SaveCommand.UnregisterPotentialTarget(View.ActiveAwareness);
        }
    }
}