﻿// --------------------------------------------------------------------------------------------------------------------
// <copyright file="VehicleTransactionsDocument.cs" company="Concept Architecture">
//   (c) 2010 Muhammad Umer Farooq
// </copyright>
// <summary>
//   Defines the VehicleTransactionsDocument type.
// </summary>
// --------------------------------------------------------------------------------------------------------------------

namespace Hisaab.Windows.Client.Documents
{
    using System;
    using System.Diagnostics.Contracts;
    using Common;
    using View;
    using ViewModel;

    /// <summary>
    /// Defines the <seealso cref="VehicleTransactionsDocument"/> type.
    /// </summary>
    public class VehicleTransactionsDocument : Document
    {
        /// <summary>
        /// VehicleTransactions view model
        /// </summary>
        private readonly VehicleTransactionsViewModel _viewModel;

        /// <summary>
        /// Initializes a new instance of the <see cref="VehicleTransactionsDocument"/> class.
        /// </summary>
        /// <param name="viewModel">
        /// The view model.
        /// </param>
        public VehicleTransactionsDocument(VehicleTransactionsViewModel viewModel)
            : base("Vehicle Management")
        {
            Contract.Requires<ArgumentNullException>(viewModel != null);
            _viewModel = viewModel;
            View = new VehicleTransactionsView { DataContext = _viewModel };
            ContextMenuGroupName = "cmVehicleTransaction";

            VehicleTransactionsViewModel.RefreshCommand.RegisterPotentialTarget(View.ActiveAwareness, _viewModel.RefreshList);
            VehicleTransactionsViewModel.EditCommand.RegisterPotentialTarget(View.ActiveAwareness, _viewModel.EditVehicleTransaction, _viewModel.CanEditVehicleTransaction);
            VehicleTransactionsViewModel.DeleteCommand.RegisterPotentialTarget(View.ActiveAwareness, _viewModel.DeleteVehicleTransaction, _viewModel.CanDeleteVehicleTransaction);
        }

        /// <summary>
        /// Documents the closed.
        /// </summary>
        public override void DocumentClosed()
        {
            VehicleTransactionsViewModel.RefreshCommand.UnregisterPotentialTarget(View.ActiveAwareness);
            VehicleTransactionsViewModel.EditCommand.UnregisterPotentialTarget(View.ActiveAwareness);
            VehicleTransactionsViewModel.DeleteCommand.UnregisterPotentialTarget(View.ActiveAwareness);
        }
    }
}