﻿// --------------------------------------------------------------------------------------------------------------------
// <copyright file="User.cs" company="Concept Architecture">
//   (c) 2010 Muhammad Umer Farooq
// </copyright>
// <summary>
//   Defines the User type.
// </summary>
// --------------------------------------------------------------------------------------------------------------------

namespace Hisaab.Windows.Client.Model
{
    using System.ComponentModel;

    /// <summary>
    /// Defines the <seealso cref="Hisaab.Windows.Client.Model.User"/> type.
    /// </summary>
    public class User : IDataErrorInfo, INotifyPropertyChanged
    {
        /// <summary>
        /// Backing field for User name
        /// </summary>
        private string _username;

        /// <summary>
        /// Backing field for password
        /// </summary>
        private string _password;

        /// <summary>
        /// Backing field for error
        /// </summary>
        private string _error = string.Empty;

        /// <summary>
        /// Occurs when a property value changes.
        /// </summary>
        public event PropertyChangedEventHandler PropertyChanged;

        /// <summary>
        /// Gets or sets the username.
        /// </summary>
        /// <value>
        /// The username.
        /// </value>
        public string Username
        {
            get
            {
                return _username;
            }

            set
            {
                _username = value;
                OnPropertyChanged("Username");
            }
        }

        /// <summary>
        /// Gets or sets the password.
        /// </summary>
        /// <value>
        /// The password.
        /// </value>
        public string Password
        {
            get
            {
                return _password;
            }

            set
            {
                _password = value;
                OnPropertyChanged("Password");
            }
        }

        #region IDataErrorInfo Members

        /// <summary>
        /// Gets or sets an error message indicating what is wrong with this object.
        /// </summary>
        /// <returns>An error message indicating what is wrong with this object. The default is an empty string ("").</returns>
        public string Error
        {
            get
            {
                return _error;
            }

            set
            {
                _error = value;
            }
        }

        /// <summary>
        /// Gets the error message for the property with the given name.
        /// </summary>
        /// <param name="columnName">Column name to get</param>
        /// <returns>The error message for the property. The default is an empty string ("").</returns>
        public string this[string columnName]
        {
            get
            {
                if (columnName == "Username")
                {
                    if (string.IsNullOrEmpty(Username))
                    {
                        _error = "Username cannot be empty";
                        return "Username cannot be empty";
                    }
                }

                if (columnName == "Password")
                {
                    if (string.IsNullOrEmpty(Password))
                    {
                        _error = "Password cannot be empty";
                        return "Password cannot be empty";
                    }
                }

                return string.Empty;
            }
        }

        #endregion IDataErrorInfo Members

        #region INotifyPropertyChanged Members

        /// <summary>
        /// Called when [property changed].
        /// </summary>
        /// <param name="propertyName">Name of the property.</param>
        private void OnPropertyChanged(string propertyName)
        {
            PropertyChangedEventHandler handler = PropertyChanged;
            if (handler != null)
            {
                handler(this, new PropertyChangedEventArgs(propertyName));
            }
        }

        #endregion INotifyPropertyChanged Members
    }
}