﻿// --------------------------------------------------------------------------------------------------------------------
// <copyright file="DialogCloser.cs" company="Concept Architecture">
//   (c) 2010 Muhammad Umer Farooq
// </copyright>
// <summary>
//   Defines the <seealso cref="Hisaab.Windows.Common.DialogCloser" /> type.
// </summary>
// --------------------------------------------------------------------------------------------------------------------

namespace Hisaab.Windows.Common
{
    using System.Windows;

    /// <summary>
    /// Defines the <seealso cref="Hisaab.Windows.Common.DialogCloser"/> type.
    /// </summary>
    public static class DialogCloser
    {
        /// <summary>
        /// Dialog result dependency property
        /// </summary>
        public static readonly DependencyProperty DialogResultProperty =
            DependencyProperty.RegisterAttached(
                "DialogResult",
                typeof(bool?),
                typeof(DialogCloser),
                new PropertyMetadata(DialogResultChanged));

        /// <summary>
        /// Sets the dialog result.
        /// </summary>
        /// <param name="target">The target window</param>
        /// <param name="value">The value of result</param>
        public static void SetDialogResult(Window target, bool? value)
        {
            target.SetValue(DialogResultProperty, value);
        }

        /// <summary>
        /// Dialogs the result changed.
        /// </summary>
        /// <param name="d">The dependency object</param>
        /// <param name="e">The <see cref="System.Windows.DependencyPropertyChangedEventArgs"/> instance containing the event data.</param>
        private static void DialogResultChanged(DependencyObject d, DependencyPropertyChangedEventArgs e)
        {
            var window = d as Window;
            if (window != null)
            {
                window.DialogResult = e.NewValue as bool?;
            }
        }
    }
}